**list** - List available profiles
==================================

Usage
------

.. code::

    e4s-cl profile list [ PATTERN ] [ OPTIONS ]

Options
----------

:code:`-s, --short`      Print the list with no formatting

Description
------------

.. automodule:: e4s_cl.cli.commands.profile.list
